package com.hp.user.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.toolkit.SqlHelper;
import com.hp.user.client.entity.*;
import com.hp.user.client.service.CustomerCompanyService;
import com.hp.user.client.service.CustomerServiceProviderEnterpriseService;
import com.hp.user.service.dao.CustomerCompanyMapper;
import com.hp.user.service.dao.CustomerServiceProviderEnterpriseMapper;
import com.hp.user.service.entity.CompanyAudit;
import com.hp.user.service.entity.CustomerCompany;
import com.hp.user.service.entity.CustomerServiceProviderEnterprise;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * <p>
 * 企业/公司 服务实现类
 * </p>
 *
 * @author 王怡静
 * @since 2020-11-20
 */
@Service
public class CustomerCompanyServiceImpl implements CustomerCompanyService {
    @Autowired
    private CustomerCompanyMapper customerCompanyMapper;
    @Autowired
    private CustomerServiceProviderEnterpriseMapper customerServiceProviderEnterpriseMapper;
    @Autowired
    private CustomerServiceProviderEnterpriseService csService;

    @Override
    public Result insert(CustomerCompanyVO company) {
    	 Result result = new Result();
    	try {
    		CustomerCompany temp = new CustomerCompany();
           
            int flag = 0;
            BeanUtils.copyProperties(company, temp);
            flag = customerCompanyMapper.insert(temp);
            // 判断数据库操作是否成功
            if (SqlHelper.retBool(flag)) {
                result.setCode("0");
            } else {
            	
                result.setCode("-1");
                result.setMessage("添加失败");
            }
    	}catch(Exception e) {
    		e.printStackTrace();
    	}
        
        return result;
    }

    @Override
    public Result delete(String companyId) {
        CustomerCompany temp;
        Result result = new Result();
        try {
        	int flag = 0;
            // 将deleted字段设置为1
            temp = customerCompanyMapper.selectById(companyId);
            if (temp == null) {
                result.setCode("-1");
                result.setMessage("未查找到此企业/服务商");
                return result;
            }
            temp.setSysDeleted((short) 1);
            flag = customerCompanyMapper.updateById(temp);
            if (SqlHelper.retBool(flag)) {
                result.setCode("0");
            } else {
                result.setCode("-1");
                result.setMessage("删除失败");
            }
        }catch(Exception e) {
        	e.printStackTrace();
        	result.setCode("-1");
        	result.setMessage("系统出现问题");
        }
        
        return result;
    }

    @Override
    public Result update(CustomerCompanyVO company) {
        CustomerCompany temp = new CustomerCompany();
        Result result = new Result();
        try {
        	int flag = 0;
            BeanUtils.copyProperties(company, temp);
            flag = customerCompanyMapper.updateById(temp);
            // 判断数据库操作是否成功
            if (SqlHelper.retBool(flag)) {
                result.setCode("0");
            } else {
                result.setCode("-1");
                result.setMessage("更新失败");
            }
        }catch(Exception e) {
        	e.printStackTrace();
        	result.setCode("-1");
        	result.setMessage("系统出现问题");
        }
        
        return result;
    }

    @Override
    public DataResult<CustomerCompanyVO> queryCompanyByCompanyId(String companyId) {
        CustomerCompanyVO customerCompanyVO = new CustomerCompanyVO();
        DataResult<CustomerCompanyVO> result = new DataResult<>();
        try {
            CustomerCompany temp = customerCompanyMapper.selectById(companyId);
            // 这个已经被删除
            if (temp == null || temp.getSysDeleted() == 1) {
                result.setCode("-1");
                result.setMessage("企业不存在/已删除");
                return result;
            } else {
                BeanUtils.copyProperties(temp, customerCompanyVO);
                result.setCode("0");
                result.setData(customerCompanyVO);
            }
        } catch(Exception e) {
        	e.printStackTrace();
        	result.setCode("-1");
        	result.setMessage("系统出现问题");
        }
        return result;
    }

    @Override
    public PageResult<CustomerCompanyVO> getCompanysPage(Long current, Integer size, Integer type) {
        PageResult<CustomerCompanyVO> result = new PageResult<>();
        List<CustomerCompanyVO> companyVOs = new ArrayList<>();
        IPage<CustomerCompany> page = new Page<>(current, size);
        QueryWrapper<CustomerCompany> queryWrapper = new QueryWrapper<>();
        try {
            queryWrapper.orderByDesc("sys_create_time");
            queryWrapper.eq("sys_deleted", 0);
            queryWrapper.eq("type", type);
            customerCompanyMapper.selectPage(page, queryWrapper);
            List<CustomerCompany> companys = page.getRecords();
            CustomerCompanyVO temp;
            for (CustomerCompany company : companys) {
                temp = new CustomerCompanyVO();
                BeanUtils.copyProperties(company, temp);
                companyVOs.add(temp);
            }
            result.setCode("0");
            result.setDataList(companyVOs);
            result.setTotal(page.getTotal());
            result.setCurrent(current);
            result.setSize(size);
        } catch(Exception e) {
        	e.printStackTrace();
        	result.setCode("-1");
        	result.setMessage("系统出现问题");
        }
        return result;
    }

    @Override
    public PageResult<CustomerCompanyVO> queryServiceProvidersByName(String name, Long current, Integer size) {
        PageResult<CustomerCompanyVO> result = new PageResult<>();
        List<CustomerCompanyVO> companyVOs = new ArrayList<>();
        IPage<CustomerCompany> page = new Page<>(current, size);
        QueryWrapper<CustomerCompany> wrapper = new QueryWrapper<>();
        try {
            wrapper.orderByDesc("sys_create_time");
            wrapper.eq("sys_deleted", 0);
            wrapper.eq("type", 0);
            if (name != null) {
                wrapper.like("name", name);
            }
            customerCompanyMapper.selectPage(page, wrapper);
            List<CustomerCompany> companys = page.getRecords();
            CustomerCompanyVO temp;
            for (CustomerCompany company : companys) {
                temp = new CustomerCompanyVO();
                BeanUtils.copyProperties(company, temp);
                companyVOs.add(temp);
            }
            result.setCode("0");
            result.setDataList(companyVOs);
            result.setTotal(page.getTotal());
            result.setCurrent(current);
            result.setSize(size);
        }catch(Exception e) {
        	e.printStackTrace();
        	result.setCode("-1");
        	result.setMessage("系统出现问题");
        }
        return result;
    }

    @Override
    public PageResult<CustomerCompanyVO> queryCompanysPageByNameAndServiceAndStatus(String name, String serviceProviderName, Integer status, Long current, Integer size) {
        PageResult<CustomerCompanyVO> result = new PageResult<>();
        List<CustomerCompanyVO> companyVOs = new ArrayList<>();
        IPage<CustomerCompany> page = new Page<>(current, size);
        QueryWrapper<CustomerCompany> wrapper = new QueryWrapper<>();
        try {
            // 关联服务商
            if (!StringUtils.isEmpty(serviceProviderName)) {
                QueryWrapper<CustomerCompany> queryWrapper = new QueryWrapper<>();
                // 先查出服务商信息，再根据服务商Id与企业Id的对应情况查企业
                queryWrapper.like("name", serviceProviderName);
                String serviceProviderId = customerCompanyMapper.selectOne(queryWrapper).getCustomerId();
                //根据服务商Id与企业Id的对应情况查企业Id
                QueryWrapper<CustomerServiceProviderEnterprise> tempWrapper = new QueryWrapper<>();
                tempWrapper.eq("service_provider_id", serviceProviderId);
                List<CustomerServiceProviderEnterprise> temp = customerServiceProviderEnterpriseMapper.selectList(tempWrapper);
                List<String> companyIds = new ArrayList<>();
                for (CustomerServiceProviderEnterprise tt : temp) {
                    companyIds.add(tt.getEnterpriseId());
                }
                wrapper.in("customer_id", companyIds);
            }
            if (status != 0) {
                wrapper.eq("status", status);
            }
            if (!StringUtils.isEmpty(name)) {
                wrapper.like("name", name);
            }
            wrapper.orderByDesc("sys_create_time");
            wrapper.eq("sys_deleted", 0);
            wrapper.eq("type", 1);
            customerCompanyMapper.selectPage(page, wrapper);
            List<CustomerCompany> companys = page.getRecords();
            CustomerCompanyVO t;
            DataResult<CustomerServiceProviderEnterpriseVO> tt;
            for (CustomerCompany company : companys) {
                t = new CustomerCompanyVO();
                BeanUtils.copyProperties(company, t);
                tt = csService.queryCsByCompanyId(company.getCustomerId());
                if (tt.getCode().equals("0")) {
                    t.setServiceProviderId(tt.getData().getServiceProviderId());
                }
                companyVOs.add(t);
            }
            result.setCode("0");
            result.setDataList(companyVOs);
            result.setTotal(page.getTotal());
            result.setCurrent(current);
            result.setSize(size);
        } catch(Exception e) {
        	e.printStackTrace();
        	result.setCode("-1");
        	result.setMessage("系统出现问题");
        }
        return result;
    }

    @Override
    public PageResult<CustomerCompanyVO> queryCompanysPageByServiceProviderIdAndNameAndStatus(String serviceProviderId, String name, Integer status, Long current, Integer size) {
        PageResult<CustomerCompanyVO> result = new PageResult<>();
        List<CustomerCompanyVO> companyVOs = new ArrayList<>();
        IPage<CustomerCompany> page = new Page<>(current, size);
        QueryWrapper<CustomerCompany> wrapper = new QueryWrapper<>();
        try {
            if(!StringUtils.isEmpty(serviceProviderId)){
                //根据服务商Id与企业Id的对应情况查企业Id
                QueryWrapper<CustomerServiceProviderEnterprise> tempWrapper = new QueryWrapper<>();
                tempWrapper.eq("service_provider_id", serviceProviderId);
                List<CustomerServiceProviderEnterprise> temp = customerServiceProviderEnterpriseMapper.selectList(tempWrapper);
                List<String> companyIds = new ArrayList<>();
                for (CustomerServiceProviderEnterprise tt : temp) {
                    companyIds.add(tt.getEnterpriseId());
                }
                wrapper.in("customer_id", companyIds);
            }
            if (status != 0) {
                wrapper.eq("status", status);
            }
            if (!StringUtils.isEmpty(name)) {
                wrapper.like("name", name);
            }
            wrapper.orderByDesc("sys_create_time");
            wrapper.eq("sys_deleted", 0);
            wrapper.eq("type", 1);
            customerCompanyMapper.selectPage(page, wrapper);
            List<CustomerCompany> companys = page.getRecords();
            CustomerCompanyVO t;
            DataResult<CustomerServiceProviderEnterpriseVO> tt;
            for (CustomerCompany company : companys) {
                t = new CustomerCompanyVO();
                BeanUtils.copyProperties(company, t);
                tt = csService.queryCsByCompanyId(company.getCustomerId());
                if (tt.getCode().equals("0")) {
                    t.setServiceProviderId(tt.getData().getServiceProviderId());
                }
                companyVOs.add(t);
            }
            result.setCode("0");
            result.setDataList(companyVOs);
            result.setTotal(page.getTotal());
            result.setCurrent(current);
            result.setSize(size);
        } catch(Exception e) {
        	e.printStackTrace();
        	result.setCode("-1");
        	result.setMessage("系统出现问题");
        }
        return result;
    }

    @Override
    public PageResult<CompanyAuditVO> getCompanyAuditsPage(Long current, Integer size) {
        PageResult<CompanyAuditVO> result = new PageResult<>();
        Page<CompanyAudit> page = new Page<>(current, size);
        try {
            List<CompanyAudit> companyAudits = customerCompanyMapper.selectCompanyAuditPage(page);
            List<CompanyAuditVO> companyAuditVOList = new ArrayList<>();
            CompanyAuditVO temp;
            for (CompanyAudit companyAudit : companyAudits) {
                temp = new CompanyAuditVO();
                BeanUtils.copyProperties(companyAudit, temp);
                companyAuditVOList.add(temp);
            }
            result.setCode("0");
            result.setDataList(companyAuditVOList);
            result.setTotal(page.getTotal());
            result.setCurrent(current);
            result.setSize(size);
        } catch(Exception e) {
        	e.printStackTrace();
        	result.setCode("-1");
        	result.setMessage("系统出现问题");
        }
        return result;
    }

    @Override
    public PageResult<CompanyAuditVO> queryCompanysPageByNameAndStatusAndCreateTime(String name, Integer status, Date startTime, Date endTime, Long current, Integer size) {
        PageResult<CompanyAuditVO> result = new PageResult<>();
        Page<CompanyAudit> page = new Page<>(current, size);
        try {
            List<CompanyAudit> companyAudits = customerCompanyMapper.queryCompanyAuditPageByNameAndStatusAndCreateTime(page, name, status, startTime, endTime);

            List<CompanyAuditVO> companyAuditVOList = new ArrayList<>();
            CompanyAuditVO temp;
            for (CompanyAudit companyAudit : companyAudits) {
                temp = new CompanyAuditVO();
                BeanUtils.copyProperties(companyAudit, temp);
                companyAuditVOList.add(temp);
            }
            result.setCode("0");
            result.setDataList(companyAuditVOList);
            result.setTotal(page.getTotal());
            result.setCurrent(current);
            result.setSize(size);
        } catch(Exception e) {
        	e.printStackTrace();
        	result.setCode("-1");
        	result.setMessage("系统出现问题");
        }
        return result;
    }

    @Override
    public PageResult<CompanyAuditVO> queryCluesPageOfContractUserByCreateTimeAndBusinessContactAndPhoneNumberAndFollowAndSourceAndPush(Date startTime, Date endTime, String businessContact, String phoneNumber, Integer follow, Integer source, Integer push, Long current, Integer size) {
        PageResult<CompanyAuditVO> result = new PageResult<>();
        Page<CompanyAudit> page = new Page<>(current, size);
        try {
            List<CompanyAudit> companyAudits = customerCompanyMapper.queryCluesPageOfContractUserByCreateTimeAndNameAndPhoneAndFollowAndSourceAndPush(page, startTime, endTime, businessContact, phoneNumber, follow, source, push);
            List<CompanyAuditVO> companyAuditVOList = new ArrayList<>();
            CompanyAuditVO temp;
            for (CompanyAudit companyAudit : companyAudits) {
                temp = new CompanyAuditVO();
                BeanUtils.copyProperties(companyAudit, temp);
                companyAuditVOList.add(temp);
            }
            result.setCode("0");
            result.setDataList(companyAuditVOList);
            result.setTotal(page.getTotal());
            result.setCurrent(current);
            result.setSize(size);
        } catch(Exception e) {
        	e.printStackTrace();
        	result.setCode("-1");
        	result.setMessage("系统出现问题");
        }
        return result;
    }
}
