package com.hp.user.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.apache.commons.lang3.StringUtils;
import org.apache.dubbo.common.utils.CollectionUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.IdWorker;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.hp.user.client.entity.DataResult;
import com.hp.user.client.entity.ElectricianGroupVO;
import com.hp.user.client.entity.FuzzyQuery;
import com.hp.user.client.entity.PageQuery;
import com.hp.user.client.entity.PageResult;
import com.hp.user.client.entity.Result;
import com.hp.user.client.service.ElectricianGroupService;
import com.hp.user.service.dao.ElectricianElectricianGroupMapper;
import com.hp.user.service.dao.ElectricianGroupMapper;
import com.hp.user.service.entity.ElectricianElectricianGroup;
import com.hp.user.service.entity.ElectricianGroup;

@Service
public class ElectricianGroupServiceImpl implements ElectricianGroupService{
	
	@Autowired
	private ElectricianGroupMapper electricianGroupMapper;
	
	@Autowired
	private ElectricianElectricianGroupMapper electricianElectricianGroupMapper;

	@Override
	@Transactional
	public Result createElectricianGroup(ElectricianGroupVO electricianGroupVO) {
		Result result = new Result();
		try {
			String electricianId = electricianGroupVO.getElectricianId();
			String serviceProviderId = electricianGroupVO.getServiceProviderId();
			String name = electricianGroupVO.getGroupName();
			String groupLeaderId = electricianGroupVO.getGroupLeader();
			if(StringUtils.isBlank(electricianId)) {
				result.setCode("-1");
				result.setMessage("组员Id不能为空！");
				return result;
			}
			if(StringUtils.isBlank(serviceProviderId)) {
				result.setCode("-1");
				result.setMessage("服务商Id不能为空！");
				return result;
			}
			if(StringUtils.isBlank(name)) {
				result.setCode("-1");
				result.setMessage("组名不能为空！");
				return result;
			}
			if(StringUtils.isBlank(groupLeaderId)) {
				result.setCode("-1");
				result.setMessage("组长Id不能为空！");
				return result;
			}
			ElectricianGroup electricianGroup = new ElectricianGroup();
			String electricianGroupId = IdWorker.getIdStr();
			BeanUtils.copyProperties(electricianGroupVO, electricianGroup);
			electricianGroup.setElectricianGroupId(electricianGroupId);
			electricianGroupMapper.insert(electricianGroup);
			String[] electricianIds = StringUtils.split(electricianId,",");
			ElectricianElectricianGroup electricianElectricianGroup;
			List<ElectricianElectricianGroup> electricianElectricianGroupList = new ArrayList<>();
			for(String id : electricianIds) {
				electricianElectricianGroup = new ElectricianElectricianGroup();
				electricianElectricianGroup.setElectricianGroupId(electricianGroupId);
				electricianElectricianGroup.setElectircianId(id);
				electricianElectricianGroupList.add(electricianElectricianGroup);
			}
//			QueryWrapper<ElectricianElectricianGroup> queryWrapper = new QueryWrapper<ElectricianElectricianGroup>();
//			queryWrapper.eq("electrician_group_id", electricianGroupId);
//			electricianElectricianGroupMapper.delete(queryWrapper);
			electricianElectricianGroupMapper.insertBatch(electricianElectricianGroupList);
		}catch(Exception e) {
			e.printStackTrace();
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public Result updateElectricianGroup(ElectricianGroupVO electricianGroupVO) {
		Result result = new Result();
		try {
			String electricianId = electricianGroupVO.getElectricianId();
			String serviceProviderId = electricianGroupVO.getServiceProviderId();
			String name = electricianGroupVO.getGroupName();
			String groupLeaderId = electricianGroupVO.getGroupLeader();
			String electricianGroupId = electricianGroupVO.getElectricianGroupId();
			if(StringUtils.isBlank(electricianGroupId)) {
				result.setCode("-1");
				result.setMessage("班组Id不能为空！");
				return result;
			}
			if(StringUtils.isBlank(electricianId)) {
				result.setCode("-1");
				result.setMessage("组员Id不能为空！");
				return result;
			}
			if(StringUtils.isBlank(serviceProviderId)) {
				result.setCode("-1");
				result.setMessage("服务商Id不能为空！");
				return result;
			}
			if(StringUtils.isBlank(name)) {
				result.setCode("-1");
				result.setMessage("组名不能为空！");
				return result;
			}
			if(StringUtils.isBlank(groupLeaderId)) {
				result.setCode("-1");
				result.setMessage("组长Id不能为空！");
				return result;
			}
			String[] electricianIds = StringUtils.split(electricianId,",");
			ElectricianElectricianGroup electricianElectricianGroup;
			List<ElectricianElectricianGroup> electricianElectricianGroupList = new ArrayList<>();
			for(String id : electricianIds) {
				electricianElectricianGroup = new ElectricianElectricianGroup();
				electricianElectricianGroup.setElectricianGroupId(electricianGroupId);
				electricianElectricianGroup.setElectircianId(id);
				electricianElectricianGroupList.add(electricianElectricianGroup);
			}
			QueryWrapper<ElectricianElectricianGroup> queryWrapper = new QueryWrapper<ElectricianElectricianGroup>();
			queryWrapper.eq("electrician_group_id", electricianGroupId);
			electricianElectricianGroupMapper.delete(queryWrapper);
			
			ElectricianGroup electricianGroup = new ElectricianGroup();
			BeanUtils.copyProperties(electricianGroupVO, electricianGroup);
			electricianGroupMapper.updateById(electricianGroup);
			electricianElectricianGroupMapper.insertBatch(electricianElectricianGroupList);
			
		}catch(Exception e) {
			e.printStackTrace();
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public DataResult<ElectricianGroupVO> queryElectricianGroupById(String electricianGroupId) {
		DataResult<ElectricianGroupVO> result = new DataResult<ElectricianGroupVO>();
		try {
			ElectricianGroup electricianGroup = electricianGroupMapper.queryElectricianGroupById(electricianGroupId);
			ElectricianGroupVO electricianGroupVO = null;
			if(null != electricianGroup) {
				electricianGroupVO =  new ElectricianGroupVO();
				BeanUtils.copyProperties(electricianGroup, electricianGroupVO);
			}
			result.setData(electricianGroupVO);
		}catch(Exception e) {
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public PageResult<ElectricianGroupVO> queryElectricianGroupByQuery(PageQuery query) {
		PageResult<ElectricianGroupVO> result = new PageResult<ElectricianGroupVO>();
		try {
			Integer page = query.getPage();
			Integer count = query.getSize();
			if(page == null || page == 0) {
				return result;
			}
			QueryWrapper<ElectricianGroup> queryWrapper = new QueryWrapper<ElectricianGroup>();
			List<FuzzyQuery> fuzzyList = query.getFuzzyList();
//			queryWrapper.eq("sys_deleted", 0);
			if(CollectionUtils.isNotEmpty(fuzzyList)) {
				for(FuzzyQuery<?> fuzzy : fuzzyList) {
					queryWrapper.like(fuzzy.getColumn(), fuzzy.getValue());
				}
			}
			List<ElectricianGroup> list = null;
			Long total = null;
			if(page == -1) {
				list = electricianGroupMapper.selectList(queryWrapper);
			}else {
//				Pagination pag1;
//				System.out.println(queryWrapper.getCustomSqlSegment());
				Page<ElectricianGroup> electricianPage = electricianGroupMapper.queryElectricianGroupByQuey(new Page<>(page,count), queryWrapper);
//				Page<ElectricianGroup> electricianPage = electricianGroupMapper.selectPage(new Page<>(page,count), queryWrapper);
				list = electricianPage.getRecords();
				total = electricianPage.getTotal();
				result.setTotal(total);
			}
			List<ElectricianGroupVO> newList = new ArrayList<>();
			ElectricianGroupVO electricianGroupVO;
			for(ElectricianGroup electricianGroup :list) {
				electricianGroupVO = new ElectricianGroupVO();
				BeanUtils.copyProperties(electricianGroup, electricianGroupVO);
				newList.add(electricianGroupVO);
			}
			result.setDataList(newList);
		}catch(Exception e) {
			e.printStackTrace();
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public Result deleteElectricianGroupById(String electricianGroupId) {
		Result result = new Result();
		try {
			ElectricianGroup electricianGroup = new ElectricianGroup();
			electricianGroup.setElectricianGroupId(electricianGroupId);
			electricianGroup.setSysDeleted(1);
			electricianGroupMapper.updateById(electricianGroup);
		}catch(Exception e) {
			e.printStackTrace();
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

}
